@@ -18,12 +18,7 @@ class popWidget : public QWidget
 	Q_OBJECT
 
 public:
-//	#if (QT_VERSION>=310)
-//	popWidget(Window * win, QWidget *parent = 0, const char *name=0, WFlags f=WStyle_Splash);
-//	#else
-	popWidget(Window * win, QWidget *parent = 0, const char *name=0, 
-					Qt::WFlags f= Qt::WindowStaysOnTopHint|Qt::X11BypassWindowManagerHint|Qt::Tool);
-//	#endif
+	popWidget(Window * win, QWidget *parent = 0, const char *name=0);
 	~popWidget();
 	
 	void popup();
